import { useEffect, useState } from 'react';
import './App.css';
import axios from 'axios';
import Item from './Item.component';

axios.defaults.baseURL = 'https://sl.aikenahac.com/api';

function App() {
  const [items, setItems] = useState<ShoppingItem[]>([]);

  useEffect(() => {
    getItems();
  }, []);

  const toggleItemBought = async (id: string, bought: boolean) => {
    await axios.put(`/items/${id}`, {
      data: {
        bought: !bought,
      },
    });

    getItems();
  };

  const getItems = async () => {
    const resp = await axios.get<{ data: ShoppingItem[] }>('/items');

    const i = resp.data.data;

    setItems(i);
  };

  return (
    <div className="app">
      {items.map((item) => (
        <Item
          name={item.attributes.name}
          bought={item.attributes.bought}
          setBought={() => toggleItemBought(item.id, item.attributes.bought)}
        />
      ))}
    </div>
  );
}

export default App;

interface ShoppingItem {
  readonly id: string;
  attributes: ShoppingItemAttributes;
}

interface ShoppingItemAttributes {
  name: string;
  bought: boolean;
}
